@@ -15,5 +15,6 @@ from .core import (NotificationMsg,
                    broadcast_warning,
                    broadcast_error,
                    broadcast_critical,
-                   priority_of)
+                   priority_of,
+                   valid_priority)
 from robotnikmq.log import log
